@@ -41,21 +41,21 @@ API_BASE_URL = API_PUBLIC_ENDPOINT
 
 
 class Client(object):
-    """A SoftLayer API client
+    """ A SoftLayer API client.
 
-    :param service_name: The name of the SoftLayer API service to query.
-    :param id: An optional object if if you're instantiating a particular
-        SoftLayer_API object. Setting an id defines this client's
+    :param service_name: the name of the SoftLayer API service to query
+    :param integer id: an optional object ID if you're instantiating a
+        particular SoftLayer_API object. Setting an ID defines this client's
         initialization parameter.
-    :param username: An optional API username if you wish to bypass the
-        package's built-in username.
-    :param api_key: An optional API key if you wish to bypass the package's
-        built in API key.
-    :param endpoint_url: The API endpoint base URL you wish to connect to.
+    :param username: an optional API username if you wish to bypass the
+        package's built-in username
+    :param api_key: an optional API key if you wish to bypass the package's
+        built in API key
+    :param endpoint_url: the API endpoint base URL you wish to connect to.
         Set this to API_PRIVATE_ENDPOINT to connect via SoftLayer's private
         network.
-    :param timeout: Timeout for API requests
-    :param verbose: When true, prints details about every HTTP request.
+    :param integer timeout: timeout for API requests
+    :param boolean verbose: prints details about every HTTP request if true
 
     Usage::
 
@@ -76,13 +76,8 @@ class Client(object):
         self._raw_headers = {}
 
         self.username = username or API_USERNAME or \
-            os.environ.get('SL_USERNAME')
-        self.api_key = api_key or API_KEY or os.environ.get('SL_API_KEY')
-
-        if not all((self.username, self.api_key)):
-            raise SoftLayerError(
-                'Must supply username and api_key')
-
+            os.environ.get('SL_USERNAME') or ''
+        self.api_key = api_key or API_KEY or os.environ.get('SL_API_KEY') or ''
         self.set_authentication(self.username, self.api_key)
 
         if id is not None:
@@ -93,17 +88,22 @@ class Client(object):
         self.timeout = timeout
 
     def add_raw_header(self, name, value):
-        """ Set HTTP headers for API calls
+        """ Set HTTP headers for API calls.
         ..  deprecated:: 2.0.0
+
+        :param name: the header name
+        :param value: the header value
+
         """
         self._raw_headers[name] = value
 
     def add_header(self, name, value):
-        """ Set a SoftLayer API call header
+        """ Set a SoftLayer API call header.
         ..  deprecated:: 2.0.0
 
-        :param name: The name of the header to add
-        :param value: The header to add.
+        :param name: the header name
+        :param value: the header value
+
         """
         name = name.strip()
         if name is None or name == '':
@@ -112,17 +112,17 @@ class Client(object):
         self._headers[name] = value
 
     def remove_header(self, name):
-        """ Remove a SoftLayer API call header
+        """ Remove a SoftLayer API call header.
         ..  deprecated:: 2.0.0
 
-        :param name: The name of the header to remove.
-        """
+        :param name: the header name
 
+        """
         if name in self._headers:
             del self._headers[name.strip()]
 
     def set_authentication(self, username, api_key):
-        """ Set user and key to authenticate a SoftLayer API call
+        """ Set user and key to authenticate a SoftLayer API call.
         ..  deprecated:: 2.0.0
 
         Use this method if you wish to bypass the API_USER and API_KEY class
@@ -131,37 +131,37 @@ class Client(object):
         See U{https://manage.softlayer.com/Administrative/apiKeychain} for more
         information.
 
-        :param username: The username to authenticate an API call.
-        :param api_key: The user's API key.
-        """
+        :param username: the username to authenticate with
+        :param api_key: the user's API key
 
+        """
         self.add_header('authenticate', {
             'username': username.strip(),
             'apiKey': api_key.strip(),
         })
 
     def set_init_parameter(self, id):
-        """ Set an initialization parameter header
+        """ Set an initialization parameter header.
         ..  deprecated:: 2.0.0
 
         Initialization parameters instantiate a SoftLayer API service object to
         act upon during your API method call. For instance, if your account has
-        a server with id number 1234, then setting an initialization parameter
+        a server with ID number 1234, then setting an initialization parameter
         of 1234 in the SoftLayer_Hardware_Server Service instructs the API to
         act on server record 1234 in your method calls.
 
-        See U{http://sldn.softlayer.com/article/Using-Initialization-Parameters-SoftLayer-API}
+        See U{http://sldn.softlayer.com/article/Using-Initialization-Parameters-SoftLayer-API}  # NOQA
         for more information.
 
-        :param id: The id number of the SoftLayer API object to instantiate
-        """
+        :param id: the ID of the SoftLayer API object to instantiate
 
+        """
         self.add_header(self._service_name + 'InitParameters', {
             'id': int(id)
         })
 
     def set_object_mask(self, mask):
-        """ Set an object mask to a SoftLayer API call
+        """ Set an object mask to a SoftLayer API call.
         ..  deprecated:: 2.0.0
 
         Use an object mask to retrieve data related your API call's result.
@@ -171,9 +171,9 @@ class Client(object):
         U{http://sldn.softlayer.com/article/Using-Object-Masks-SoftLayer-API}
         for more information.
 
-        :param mask: The object mask you wish to define
-        """
+        :param mask: the object mask you wish to define
 
+        """
         header = 'SoftLayer_ObjectMask'
 
         if isinstance(mask, dict):
@@ -182,43 +182,42 @@ class Client(object):
         self.add_header(header, {'mask': mask})
 
     def set_result_limit(self, limit, offset=0):
-        """ Set a result limit on a SoftLayer API call
+        """ Set a result limit on a SoftLayer API call.
         ..  deprecated:: 2.0.0
 
         Many SoftLayer API methods return a group of results. These methods
         support a way to limit the number of results retrieved from the
         SoftLayer API in a way akin to an SQL LIMIT statement.
 
-        :param limit: The number of results to limit a SoftLayer API call to.
-        :param offset: An optional offset to begin a SoftLayer API call's
-        returned result at.
-        """
+        :param limit: the number of results to limit a SoftLayer API call to
+        :param offset: An optional offset at which to begin a SoftLayer API
+        call's returned result
 
+        """
         self.add_header('resultLimit', {
             'limit': int(limit),
             'offset': int(offset)
         })
 
     def __getitem__(self, name):
-        """ Get a SoftLayer Service
+        """ Get a SoftLayer Service.
 
         :param name: The name of the service. E.G. SoftLayer_Account
+
         """
         if not name.startswith(self._prefix):
             name = self._prefix + name
         return Service(self, name)
 
-    def __format_filter_dict(self, d):
-        for key, value in d.iteritems():
-            if isinstance(value, dict):
-                d[key] = self.__format_filter_dict(value)
-                return d
-            else:
-                d[key] = {'operation': value}
-                return d
-
     def __call__(self, service, method, *args, **kwargs):
-        """ Place a SoftLayer API call """
+        """ Perform a SoftLayer API call.
+
+        :param service: the name of the SoftLayer API service
+        :param method: the method to call on the service
+        :param dict *args: arguments for the specified method
+        :param dict **kwargs: response-level arguments (limit, offset, etc.)
+
+        """
         objectid = kwargs.get('id')
         objectmask = kwargs.get('mask')
         objectfilter = kwargs.get('filter')
@@ -249,14 +248,10 @@ class Client(object):
             headers[service + 'InitParameters'] = {'id': int(objectid)}
 
         if objectmask is not None:
-            mheader = self._prefix + 'ObjectMask'
-            if isinstance(objectmask, dict):
-                mheader = '%sObjectMask' % service
-            headers[mheader] = {'mask': objectmask}
+            headers.update(self.__format_object_mask(objectmask, service))
 
         if objectfilter is not None:
-            headers['%sObjectFilter' % service] = \
-                self.__format_filter_dict(objectfilter)
+            headers['%sObjectFilter' % service] = objectfilter
 
         if limit:
             headers['resultLimit'] = {
@@ -268,8 +263,33 @@ class Client(object):
                              http_headers=http_headers, timeout=self.timeout,
                              verbose=self.verbose)
 
+    def __format_object_mask(self, objectmask, service):
+        """ Format new and old style object masks into proper headers.
+
+        :param objectmask: a string- or dict-based object mask
+        :param service: a SoftLayer API service name
+
+        """
+        if isinstance(objectmask, dict):
+            mheader = '%sObjectMask' % service
+        else:
+            mheader = self._prefix + 'ObjectMask'
+
+            objectmask = objectmask.strip()
+            if objectmask.startswith('mask'):
+                objectmask = objectmask[4:]
+                if objectmask[0] == '.':
+                    objectmask = objectmask[1:]
+                elif objectmask[0] == '[' and objectmask[-1] == ']':
+                    objectmask = objectmask[1:-1]
+                else:
+                    raise SoftLayerError('Malformed Mask: %s' % objectmask)
+            objectmask = "mask[%s]" % objectmask
+
+        return {mheader: {'mask': objectmask}}
+
     def __getattr__(self, name):
-        """ Attempt a SoftLayer API call
+        """ Attempt a SoftLayer API call.
         ..  deprecated:: 2.0.0
 
         Use this as a catch-all so users can call SoftLayer API methods
@@ -277,6 +297,9 @@ class Client(object):
         relating to their client object doesn't exist then assume the user is
         attempting a SoftLayer API call and return a simple function that makes
         an XML-RPC call.
+
+        :param name: method name
+
         """
         if name in ["__name__", "__bases__"]:
             raise AttributeError("'Obj' object has no attribute '%s'" % name)
