@@ -26,7 +26,7 @@
 """
 SoftLayer Python API Client
 ~~~~~~~~~~~~~~~~~~~~~~~~~~~
-A library to contact SoftLayer's backend services through the XML-RPC interface
+A library to use SoftLayer's API through the XML-RPC interface.
 See U{http://sldn.softlayer.com/article/Python}
 
 
@@ -41,13 +41,17 @@ usage:
 """
 from SoftLayer.consts import VERSION
 
+from API import Client, API_PUBLIC_ENDPOINT, API_PRIVATE_ENDPOINT
+from DNS import DNSManager
+from CCI import CCIManager
+from metadata import MetadataManager
+from SoftLayer.exceptions import *  # NOQA
+
 __title__ = 'SoftLayer'
 __version__ = VERSION
 __author__ = 'SoftLayer Technologies, Inc.'
 __license__ = 'The BSD License'
 __copyright__ = 'Copyright 2013 SoftLayer Technologies, Inc.'
-__all__ = ['Client', 'SoftLayerError', 'API_PUBLIC_ENDPOINT',
-           'API_PRIVATE_ENDPOINT']
-
-from API import Client, API_PUBLIC_ENDPOINT, API_PRIVATE_ENDPOINT
-from SoftLayer.exceptions import SoftLayerError
+__all__ = ['Client', 'SoftLayerError', 'SoftLayerAPIError',
+           'API_PUBLIC_ENDPOINT', 'API_PRIVATE_ENDPOINT',
+           'DNSManager', 'CCIManager', 'MetadataManager']
