@@ -1,5 +1,4 @@
-
 try:
     from SoftLayer.transport.requests_transport import make_api_call
-except ImportError:
+except ImportError:  # pragma: no cover
     from SoftLayer.transport.xmlrpclib_transport import make_api_call
